<?php

namespace Drupal\taxonomy_access_fix;

/**
 * Provides a fallback for \Drupal\Core\Entity\BundlePermissionHandlerTrait.
 *
 * @todo Remove in 4.x.
 *
 * @see \Drupal\Core\Entity\BundlePermissionHandlerTrait
 */
trait BundlePermissionHandlerFallbackTrait {

  /**
   * Builds a permissions array for the supplied bundles.
   *
   * @param \Drupal\Core\Entity\EntityInterface[] $bundles
   *   An array of bundles to generate permissions for.
   * @param callable $permission_builder
   *   A callable to generate the permissions for a particular bundle. Returns
   *   an array of permissions. See PermissionHandlerInterface::getPermissions()
   *   for the array structure.
   *
   * @return array
   *   Permissions array. See PermissionHandlerInterface::getPermissions() for
   *   the array structure.
   *
   * @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  protected function generatePermissions(array $bundles, callable $permission_builder) {
    $permissions = [];
    foreach ($bundles as $bundle) {
      $permissions += $permission_builder($bundle);
    }
    return $permissions;
  }

}
